@@ -1,10 +1,12 @@
 import pytest
-from bionumpy.sequences import Sequence
+from bionumpy.encoded_array import EncodedArray
 import numpy as np
 
+
 @pytest.fixture
 def sequence():
-    return (np.array([[1, 2], [2, 3]], dtype=np.uint8)+64).view(Sequence)
+    return EncodedArray(np.array([[1, 2], [2, 3]], dtype=np.uint8)+64)
+
 
 def _test_sequence_repr(sequence):
     assert repr(sequence).replace("\n", "") == "Sequence([[65, 66] [66 67]])"
@@ -13,17 +15,18 @@ def _test_sequence_repr(sequence):
 def test_sequence_str(sequence):
     assert str(sequence) == """['AB' 'BC']"""
 
+
 def test_concat_sequenc(sequence):
     cat = np.concatenate([sequence, sequence])
-    assert isinstance(cat, Sequence)
+    assert isinstance(cat, EncodedArray)
 
 
 def test_iter(sequence):
     for elem in sequence.ravel():
-        assert isinstance(elem, Sequence), (elem, type(elem), elem.view(Sequence))
+        assert isinstance(elem, EncodedArray), (elem, type(elem), elem.view(EncodedArray))
 
 
 def test_getitem(sequence):
     sequence = sequence.ravel()
     for i in range(len(sequence)):
-        assert isinstance(sequence[i], Sequence)
+        assert isinstance(sequence[i], EncodedArray)
